from typing import List

import pytest
from _pytest.fixtures import SubRequest


@pytest.hookimpl(tryfirst=True)
def pytest_collection_modifyitems(
    session, config, items: List[pytest.Item]
) -> None:
    return


def setup_test_environement():
    print(
        """
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
A amora adoça mais na boca de quem namora. 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    Mantido com <3 por `RexData@Stone`
"""
    )


def teardown_test_environment():
    print("todo: Print table with total bytes billed, query time, etc")


@pytest.fixture(autouse=True, scope="session")
def amora_test_environment(request: SubRequest) -> None:
    """
    Ensure that everything that Amora needs is loaded and has its testing environment setup.

    """
    setup_test_environement()
    request.addfinalizer(teardown_test_environment)



from typing import Optional, List

import pytest
import typer


Models = List[str]

app = typer.Typer()


@app.command()
def test(
    models: Optional[Models] = typer.Option(
        [],
        "--model",
        help="A model to be compiled. This option can be passed multiple times.",
    ),
) -> None:
    """
    Runs tests on data in deployed models. Run this after `amora materialize`
    to ensure that the date state is up-to-date.
    """
    return_code = pytest.main(["-n", "auto"])
    raise typer.Exit(return_code)


if __name__ == "__main__":
    app()



import typer
from typing import Optional, List

from amora.models import list_target_files
from amora import materialization


Models = List[str]
app = typer.Typer()


@app.command()
def materialize(
    models: Optional[Models] = typer.Option(
        [],
        "--model",
        help="A model to be compiled. This option can be passed multiple times.",
    ),
    draw_dag: bool = typer.Option(False, "--draw-dag"),
) -> None:
    """
    Executes the compiled SQL againts the current target database.
    """
    model_to_task = {}

    for target_file_path in list_target_files():
        if models and target_file_path.stem not in models:
            continue

        task = materialization.Task.for_target(target_file_path)
        model_to_task[task.model.__name__] = task

    dag = materialization.DependencyDAG.from_tasks(tasks=model_to_task.values())

    if draw_dag:
        dag.draw()

    for model in dag:
        try:
            task = model_to_task[model]
        except KeyError:
            typer.echo(f"⚠️  Skipping `{model}`")
            continue
        else:
            table = materialization.materialize(
                sql=task.sql_stmt, model=task.model
            )
            if table is None:
                continue

            typer.echo(f"✅  Created `{model}` as `{table.full_table_id}`")
            typer.echo(f"    Rows: {table.num_rows}")
            typer.echo(f"    Bytes: {table.num_bytes}")


if __name__ == "__main__":
    app()



import os
from pathlib import Path

from pydantic import BaseSettings

ROOT_PATH = Path(__file__).parent.parent
AMORA_MODULE_PATH = ROOT_PATH.joinpath("amora")


class Settings(BaseSettings):
    TARGET_PROJECT: str
    TARGET_SCHEMA: str
    TARGET_PATH: str = AMORA_MODULE_PATH.joinpath("target").as_posix()
    MODELS_PATH: str = ROOT_PATH.joinpath("dbt/models").as_posix()

    CLI_CONSOLE_MAX_WIDTH: int = 160

    class Config:
        env_prefix = "AMORA_"


settings = Settings()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['amora', 'amora._cli', 'amora.providers', 'amora.tests']

package_data = \
{'': ['*'], 'amora': ['target/.gitkeep', 'templates/*']}

install_requires = \
['Jinja2>=2.11.3,<3.0.0',
 'matplotlib>=3.4.2,<4.0.0',
 'networkx[all]>=2.6.3,<3.0.0',
 'numpy>=1.21.1,<2.0.0',
 'pandas>=1.3.0,<2.0.0',
 'pytest-xdist[psutil]>=2.4.0,<2.5.0',
 'pytest>=6.2.5,<7.0.0',
 'rich>=10.13.0,<11.0.0',
 'sqlalchemy-bigquery==1.2.1',
 'sqlmodel>=0.0.4,<0.0.5',
 'typer[all]>=0.4.0,<0.5.0']

setup_kwargs = {
    'name': 'amora',
    'version': '0.1.0',
    'description': 'Amora Data Build Tool',
    'long_description': None,
    'author': 'diogommartins',
    'author_email': 'diogommartins.dev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9.6,<3.10',
}


setup(**setup_kwargs)
